@@ -12,25 +12,24 @@ sub new {
     $self->init; ### sets bitmap undef, componentsbag new
 }
 
-sub addBitmap { ### sets bitmap
+sub addBitmap { ### sets bitmapmatrix
   my ($self, $bitmap) = @_;
 
-  not defined($bitmap) or die "OnePassFilterAlgorithmBlue : bitmap of the blue dither algorithm is empty !";
+  defined($bitmap) or die "OnePassFilterAlgorithmBlue : bitmap of the blue dither algorithm is empty !";
   
   $self->{bitmap} = $bitmap;
 }
 
+### returns a matrixbitmap, unwritten to file
 sub pass {
-  my $self = shift;
+  my ($self, $pngfilename) = @_;
 
-  ######### FIXME TODO
-  
   ### 1 of el1 means one follower
-  my $secondel1 = MatrixBitmapLoaderComponent->new;
-  my $firstel1 = BagElement->new->setNext($secondel1);
+  my $secondel1 = BlueDitherComponent->new;
+  my $firstel1 = MatrixBitmapLoaderComponent->new->setNext($secondel1);
   $self->addBagElement1($firstel1);
   
-  return SUPER::OnePassBitmapAlgorithm->pass->(OnePassSystemBlue->new); 
+  return SUPER::OnePassBitmapAlgorithm->pass->(OnePassSystemBlue->new($pngfilename)); 
 }
 
 1;
